% Archivo: bit_derivation.m
%
% Función que calcula un bit de la fingerprint
%
% Parámetros:
%   e=energia de la banda
%   e_banterior=energia de la banda anterior
%   e_tanterior=energia de la banda en el periodo anterior
%   e_tb=energia de la banda posterior en el periordo anterior

function F=bit_derivation(e,e_banterior,e_tanterior,e_tb)

ED=e-e_banterior-(e_tanterior-e_tb);

if ED>0
    F=1;
else 
    F=0;
end
